<?php

namespace EventPortal\Domain\Email\Models;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Model;
use EventPortal\Domain\Table\Concerns\HasTable;
use EventPortal\Enums\EmailType;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Spatie\Enum\Laravel\HasEnums;

class Email extends Model
{
    use HasEnums, HasTable;

    public const KEY = 'email';

    protected $table = 'event_emails';

    /** @var array<string> */
    protected $fillable = [
        'event_id',
        'type',
        'subject',
        'sender_address',
        'reply_to_address',
    ];

    /** @var array<string> */
    protected $with = [
        'event',
    ];

    /** @var array<string,mixed> */
    protected $enums = [
        'type' => EmailType::class,
    ];

    /** @var array<string> */
    protected $casts = [
        'type' => 'integer',
    ];

    public function event(): BelongsTo
    {
        return $this->belongsTo(Event::class);
    }

    public function scopeForEvent(Builder $query, Event $event): Builder
    {
        return $query->where('event_id', $event->id);
    }
}
