<?php

namespace EventPortal\Tests\Feature\Admin\Email;

use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Domain\Email\Models\Email;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Permission\Models\Permission;
use EventPortal\Http\Middleware\CurrentTeam;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Spatie\Snapshots\MatchesSnapshots;

class EmailShowTest extends TestCase
{
    use DatabaseMigrations, MatchesSnapshots;

    /** @test **/
    public function can_view_an_individual_email()
    {
        $admin = factory(Admin::class)->create();
        $event = factory(Event::class)->create([
            'name' => 'Hello World!',
        ]);
        $email = factory(Email::class)->create([
            'event_id' => $event,
        ]);

        $admin->givePermissionTo([
            factory(Permission::class)->create([
                'name' => 'email.show',
            ]),
            factory(Permission::class)->create([
                'name' => 'email.update',
            ]),
        ]);

        $this->withoutMiddleware(CurrentTeam::class)
            ->assertMatchesJsonSnapshot(
                $this->actingAs($admin->user)
                    ->get(route('admin.email.show', [
                        'event' => $event->id,
                        'email' => $email->id,
                    ]))->props()
            );
    }
}
