<?php

namespace EventPortal\Tests\Feature\Admin\User;

use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Domain\Team\Models\Team;
use EventPortal\Domain\User\Models\User;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Spatie\Snapshots\MatchesSnapshots;

class UserStoreTest extends TestCase
{
    use RefreshDatabase, MatchesSnapshots, SeedRolesAndPermissions;

    /** @test **/
    public function the_create_view_supplies_the_correct_data_to_the_frontend()
    {
        factory(Team::class)->state('snapshot')->create();

        $this->assertMatchesJsonSnapshot(
            $this
                ->actingAsSuperAdmin()
                ->get(route('admin.user.create'))->props()
        );
    }

    /** @test */
    public function a_user_can_be_created()
    {
        $this
            ->actingAsSuperAdmin()
            ->followingRedirects()
            ->post(route('admin.user.store'), [
                'first_name' => 'Firstname',
                'last_name' => 'Lastname',
                'email' => 'test@example.com',
                'role_id' => 1,
            ])
            ->assertOk();

        $user = User::where('email', 'test@example.com')->first();

        $this->assertEquals(
            route('admin.user.show', ['admin' => $user->admin]),
            url()->current()
        );

        $this->assertDatabaseHas('users', [
            'first_name' => 'Firstname',
            'last_name' => 'Lastname',
            'email' => 'test@example.com',
        ]);
    }

    /** @test **/
    public function the_first_name_last_name_and_email_are_required()
    {
        $this->markTestSkipped('Need to complete');

        $admin = factory(Admin::class)->create();

        $this
            ->actingAsAdmin($admin)
            ->post(route('admin.user.store'), [
                'first_name' => null,
                'last_name' => null,
            ])
            ->assertSessionHasErrors([
                'first_name',
                'last_name',
            ]);

        $this->assertEquals(1, User::count()); // Admin user already exists
    }
}
